import {RcsbFv3DCustom} from "../../RcsbFv3D/RcsbFv3DCustom";
import {RcsbFvStructureConfigInterface} from "../../RcsbFvStructure/RcsbFvStructure";
import {
    CustomViewInterface,
    FeatureBlockInterface
} from "../../RcsbFvSequence/SequenceViews/CustomView/CustomView";
import {
    LoadMethod,
    LoadMolstarInterface, LoadMolstarReturnType
} from "../../RcsbFvStructure/StructureViewers/MolstarViewer/MolstarActionManager";
import {ViewerProps} from "@rcsb/rcsb-molstar/build/src/viewer";

import {
    fetchHtpDescriptor,
    fetchPdbtmJsvLibDescriptor,
    htpDescriptorToTrackData,
    jsvLibDescriptorToTrackData
} from "./UniTmpHelper";
import { updateSiteColors } from "./UniTmpColor";
import { fvConfig, rowConfig } from "./FeatureViewConfig";
import { RcsbPreset } from "@rcsb/rcsb-molstar/build/src/viewer/helpers/preset";

const side1 = "Inside";
const htpEntry = "GLPA_HUMAN";
const pdbEntry = "1afo";
const pdbtmEntry = `${pdbEntry}_A`;




const block: FeatureBlockInterface<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType> = {
    blockId:"MyBlock_1",
    featureViewConfig: [fvConfig]
};

const customConfig: CustomViewInterface<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType> = {
    blockConfig:[block]
}

const sequenceConfig = {
    title: "UniTmp example",
    subtitle: `HTP entry ${htpEntry}`,
    config: customConfig
};

const molstarConfig: RcsbFvStructureConfigInterface<LoadMolstarInterface<unknown,unknown>,{viewerProps:Partial<ViewerProps>}> = {
    loadConfig: {
        loadMethod: LoadMethod.loadStructureFromUrl,
        loadParams: {
            //url: `https://pdbtm.unitmp.org/api/v1/entry/${pdbEntry}.trpdb`,
            url: `https://www.ebi.ac.uk/pdbe/entry-files/download/${pdbEntry}_updated.cif`,
            format: 'mmcif',
            isBinary: false,
            id: `${pdbEntry}_model`,
            reprProvider: RcsbPreset
        }
    },
    structureViewerConfig: {
        viewerProps:{
            showImportControls: true,
            showSessionControls: false,
            //extensions: 
        }
    }
};

document.addEventListener("DOMContentLoaded", (event) => {
    (async function(event) {
        updateSiteColors(side1);
        const htpDescriptor = await fetchHtpDescriptor(htpEntry);
        const jsvlibDescriptor = await fetchPdbtmJsvLibDescriptor(pdbtmEntry);

        console.log(htpDescriptor);

        let sequence = htpDescriptor.Sequence.Seq;
        sequence = sequence.replace(/\s+/g, '');

        fvConfig.boardConfig.length = parseInt(htpDescriptor.Sequence['@attributes'].Length);
        fvConfig.rowConfig[0].rowTitle = `${htpDescriptor['@attributes'].id} sequence`;
        rowConfig[0].trackData![0].value = sequence;
        rowConfig.push(...htpDescriptorToTrackData(htpDescriptor));

        rowConfig.push(...jsvLibDescriptorToTrackData(jsvlibDescriptor));


        const panel3d = new RcsbFv3DCustom({
            elementId: "null",
            structurePanelConfig: molstarConfig,
            sequencePanelConfig: sequenceConfig
        });
        panel3d.render();
    })();
});
